CreateUser class
Constructors
-
CreateUser({required String username, required String firstName, required String lastName, required String email, required String password, required String groupId, bool acceptTermsAndConditions = false, List<
String> roles = const [], num? expiringAt, bool enabled = true}) - Returns a new CreateUser instance.
Properties
- acceptTermsAndConditions ↔ bool
-
getter/setter pair
- email ↔ String
-
getter/setter pair
- enabled ↔ bool
-
getter/setter pair
- expiringAt ↔ num?
-
Please note: This property should have been non-nullable! Since the specification file
does not include a default value (using the "default:" property), however, the generated
source code must fall back to having a nullable type.
Consider adding a "default:" property in the specification file to hide this note.
getter/setter pair
- firstName ↔ String
-
getter/setter pair
- groupId ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastName ↔ String
-
getter/setter pair
- password ↔ String
-
getter/setter pair
-
roles
↔ List<
String> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- username ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → CreateUser? -
Returns a new CreateUser instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< CreateUser> -
mapFromJson(
dynamic json) → Map< String, CreateUser> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< CreateUser> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.