GroupsApi class

Constructors

GroupsApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

approveGroupRequest(String groupId, String requestId, {String? lang}) Future<void>
Approve group request
approveGroupRequestWithHttpInfo(String groupId, String requestId, {String? lang}) Future<Response>
Approve group request
createGroup(GroupCreate groupCreate) Future<GroupCreated?>
Create Group
createGroupWithHttpInfo(GroupCreate groupCreate) Future<Response>
Create Group
deleteGroup(String groupId) Future<void>
Delete Group
deleteGroupRequest(String groupId, String requestId, {String? lang}) Future<void>
Reject group request
deleteGroupRequestWithHttpInfo(String groupId, String requestId, {String? lang}) Future<Response>
Reject group request
deleteGroupWithHttpInfo(String groupId) Future<Response>
Delete Group
getAllGroupRoles() Future<List<Role>?>
List all available group roles
getAllGroupRolesWithHttpInfo() Future<Response>
List all available group roles
getGroupById(String groupId) Future<Group?>
Retrieve group
getGroupByIdWithHttpInfo(String groupId) Future<Response>
Retrieve group
getGroupRequests(String groupId) Future<List<GroupsRequest>?>
Retrieve group requests
getGroupRequestsWithHttpInfo(String groupId) Future<Response>
Retrieve group requests
getGroupRoles(String groupId) Future<List<Role>?>
Retrieve group Roles
getGroupRolesWithHttpInfo(String groupId) Future<Response>
Retrieve group Roles
getGroups() Future<List<Group>?>
List groups
getGroupsWithHttpInfo() Future<Response>
List groups
getGroupUsers(String groupId) Future<List<User>?>
Retrieve Group Users
getGroupUsersWithHttpInfo(String groupId) Future<Response>
Retrieve Group Users
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateGroup(String groupId, GroupUpdate groupUpdate) Future<void>
Update Group
updateGroupRoles(String groupId, RolesUpdate rolesUpdate) Future<Group>
Update Group Roles
updateGroupRolesWithHttpInfo(String groupId, RolesUpdate rolesUpdate) Future<Response>
Update Group Roles
updateGroupWithHttpInfo(String groupId, GroupUpdate groupUpdate) Future<Response>
Update Group

Operators

operator ==(Object other) bool
The equality operator.
inherited