PublicApi class

Constructors

PublicApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publicSignupOrganizationPost(OrgSignup orgSignup) Future<void>
Register an organization
publicSignupOrganizationPostWithHttpInfo(OrgSignup orgSignup) Future<Response>
Register an organization
publicSignupUserPost(UserSignup userSignup) Future<void>
Register an user
publicSignupUserPostWithHttpInfo(UserSignup userSignup) Future<Response>
Register an user
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited