publicSignupUserPostWithHttpInfo method

Future<Response> publicSignupUserPostWithHttpInfo(
  1. UserSignup userSignup
)

Register an user

Registers a new user. Before being actually registered on the platform, the user's request must be approved from the admin of the group.

Note: This method returns the HTTP Response.

Parameters:

Implementation

Future<Response> publicSignupUserPostWithHttpInfo(
  UserSignup userSignup,
) async {
  // ignore: prefer_const_declarations
  final path = r'/public/signup/user';

  // ignore: prefer_final_locals
  Object? postBody = userSignup;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const contentTypes = <String>['application/json'];

  return apiClient.invokeAPI(
    path,
    'POST',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
  );
}