UserSignup class

Constructors

UserSignup({required String username, required String firstName, required String lastName, required String email, required String password, required String group, List<String> roles = const []})
Returns a new UserSignup instance.

Properties

email String
getter/setter pair
firstName String
getter/setter pair
group String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
lastName String
getter/setter pair
password String
getter/setter pair
roles List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) UserSignup?
Returns a new UserSignup instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<UserSignup>
mapFromJson(dynamic json) Map<String, UserSignup>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<UserSignup>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.